Converts a mighty_study or mighty_domain object into a flat dataframe of column definitions.
Arguments
- x
A mighty_study or mighty_domain object.
Value
A tibble with one row per column containing:
- table_id
Table identifier
- table_label
Table label/description
- order
Column order within table
- id
Column name
- label
Column label
- origin
Origin type (e.g., "Predecessor", "Derived")
- key
Logical, whether column is a key
- is_core
Logical, whether column is a core variable
- core
String, whether a column is Req, Cond or Perm
- method
Derivation method
- codelist
Codelist reference
- format_type
Data type ("C" or "N")
- format_length
Maximum length
- format_display
Display format
- comment
Comment
Examples
study <- mighty_study(
path = system.file("examples", package = "mighty.metadata")
)
mdcol <- create_md_col(study)